sdv.constraints.Inequality
==========================

.. currentmodule:: sdv.constraints

.. autoclass:: Inequality

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Inequality.__init__
      ~Inequality.filter_valid
      ~Inequality.fit
      ~Inequality.fit_transform
      ~Inequality.from_dict
      ~Inequality.is_valid
      ~Inequality.reverse_transform
      ~Inequality.to_dict
      ~Inequality.transform
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Inequality.constraint_columns
   
   